/*
 * Drop all Flow Processor tables.
 */
 
DROP TABLE FP_OPTION CASCADE CONSTRAINTS ; 
DROP TABLE FP_SUBMITTAL_PREPROCESS_PARAM CASCADE CONSTRAINTS ; 
DROP TABLE FP_SUBMITTAL_PREPROCESS_XREF CASCADE CONSTRAINTS ; 
DROP TABLE FP_SUBMITTAL_PREPROCESS CASCADE CONSTRAINTS ; 
DROP TABLE FP_SUBMITTAL_EXPORT_PARAM CASCADE CONSTRAINTS ; 
DROP TABLE FP_SUBMITTAL_EXPORT_XREF CASCADE CONSTRAINTS ; 
DROP TABLE FP_SUBMITTAL_EXPORT CASCADE CONSTRAINTS ; 
DROP TABLE FP_SUBMITTAL CASCADE CONSTRAINTS ; 
DROP TABLE FP_SUBMITTAL_MODEL_SQL CASCADE CONSTRAINTS ; 
DROP TABLE FP_SUBMITTAL_MODEL_PRESQL CASCADE CONSTRAINTS ; 
DROP TABLE FP_SUBMITTAL_MODEL CASCADE CONSTRAINTS ; 
DROP SEQUENCE MASTER.SEQ_FP_EXECUTION_ID;

/*
 * Flow Processor object create scripts
 */

CREATE SEQUENCE SEQ_FP_EXECUTION_ID 
START WITH 1 
INCREMENT BY 1 
MINVALUE 1 NOCYCLE
NOORDER ;

 
CREATE TABLE FP_OPTION ( 
  OPTION_NAME     VARCHAR2 (50)  NOT NULL, 
  OPTION_DESC     VARCHAR2 (200)  NOT NULL, 
  VALUE_STRING    VARCHAR2 (4000), 
  VALUE_NUMBER    NUMBER (20,10), 
  VALUE_DATE      DATE, 
  USER_LAST_UPDT  VARCHAR2 (30)  NOT NULL, 
  TMSP_LAST_UPDT  DATE          NOT NULL, 
  CONSTRAINT PK_FP_OPTION
  PRIMARY KEY ( OPTION_NAME ) ) ; 


CREATE TABLE FP_SUBMITTAL_MODEL ( 
  SUBMITTAL_MODEL_CODE        VARCHAR2 (50)  NOT NULL, 
  SUBMITTAL_MODEL_DESC        VARCHAR2 (200)  NOT NULL, 
  CDX_DATA_FLOW_CODE          VARCHAR2 (50)  NOT NULL, 
  CDX_DOC_TYPE_CODE           VARCHAR2 (50)  NOT NULL, 
  CDX_FLOW_SCHEMA             VARCHAR2 (100), 
  CDX_FLOW_OPERATION          VARCHAR2 (100), 
  CDX_DOC_TEMPLATE_FILENAME   VARCHAR2 (500), 
  CDX_DATA_SET_XSLT_FILENAME  VARCHAR2 (500), 
  OUTPUT_BASE_FILENAME        VARCHAR2 (100)  NOT NULL, 
  OUTPUT_ROOT_OPEN_TAG        VARCHAR2 (2000), 
  OUTPUT_ROOT_CLOSE_TAG       VARCHAR2 (50), 
  SEARCH_SQL_ID               VARCHAR2 (100)  NOT NULL, 
  INTERMEDIATE_ROOT_TAG       VARCHAR2 (30)  NOT NULL, 
  USER_LAST_UPDT              VARCHAR2 (30)  NOT NULL, 
  TMSP_LAST_UPDT              DATE          NOT NULL, 
  PROCESS_TEMP_ROWS           VARCHAR2 (10), 
  TEMP_DIRECTORY              VARCHAR2 (500), 
  CDX_DATA_SERVICE            VARCHAR2 (100), 
  XML_VALIDATE_FLAG           CHAR (1), 
  CONSTRAINT PK_FP_SUBMITTAL_MODEL
  PRIMARY KEY ( SUBMITTAL_MODEL_CODE ) ) ; 


CREATE TABLE FP_SUBMITTAL ( 
  SUBMITTAL_CODE          VARCHAR2 (50)  NOT NULL, 
  SUBMITTAL_DESC          VARCHAR2 (200)  NOT NULL, 
  SUBMITTAL_MODEL_CODE    VARCHAR2 (50)  NOT NULL, 
  USE_LAST_RUN_DATE_FLAG  CHAR (1), 
  LAST_RUN_DATE           DATE, 
  CACHE_FLAG              CHAR (1)      NOT NULL, 
  USER_LAST_UPDT          VARCHAR2 (30)  NOT NULL, 
  TMSP_LAST_UPDT          DATE          NOT NULL, 
  CONSTRAINT PK_FP_SUBMITTAL
  PRIMARY KEY ( SUBMITTAL_CODE ) ) ; 

ALTER TABLE FP_SUBMITTAL ADD  CONSTRAINT FK_FP_SUBMITTAL_MODEL_2
 FOREIGN KEY (SUBMITTAL_MODEL_CODE) 
  REFERENCES FP_SUBMITTAL_MODEL (SUBMITTAL_MODEL_CODE) ;


CREATE TABLE FP_SUBMITTAL_MODEL_PRESQL ( 
  SUBMITTAL_MODEL_CODE  VARCHAR2 (50)  NOT NULL, 
  UPDATE_SQL_ID         VARCHAR2 (200)  NOT NULL, 
  UPDATE_SQL_DESC       VARCHAR2 (200)  NOT NULL, 
  ORDER_NUM             NUMBER (2)    NOT NULL, 
  ACTIVE_FLAG           CHAR (1)      NOT NULL, 
  USER_LAST_UPDT        VARCHAR2 (30)  NOT NULL, 
  TMSP_LAST_UPDT        DATE          NOT NULL, 
  CONSTRAINT PK_FP_SUBMITTAL_MODEL_PRESQL
  PRIMARY KEY ( SUBMITTAL_MODEL_CODE, UPDATE_SQL_ID ) ) ; 

ALTER TABLE FP_SUBMITTAL_MODEL_PRESQL ADD  CONSTRAINT FK_FP_SUBMITTAL_MODEL_3
 FOREIGN KEY (SUBMITTAL_MODEL_CODE) 
  REFERENCES FP_SUBMITTAL_MODEL (SUBMITTAL_MODEL_CODE) ;


CREATE TABLE FP_SUBMITTAL_MODEL_SQL ( 
  SUBMITTAL_MODEL_CODE         VARCHAR2 (50)  NOT NULL, 
  RETRIEVE_SQL_ID              VARCHAR2 (200)  NOT NULL, 
  RETRIEVE_SQL_DESC            VARCHAR2 (200)  NOT NULL, 
  INTERMEDIATE_LOCAL_ROOT_TAG  VARCHAR2 (30)  NOT NULL, 
  ORDER_NUM                    NUMBER (2)    NOT NULL, 
  ACTIVE_FLAG                  CHAR (1)      NOT NULL, 
  USER_LAST_UPDT               VARCHAR2 (30)  NOT NULL, 
  TMSP_LAST_UPDT               DATE          NOT NULL, 
  CONSTRAINT PK_FP_SUBMITTAL_MODEL_SQL
  PRIMARY KEY ( SUBMITTAL_MODEL_CODE, RETRIEVE_SQL_ID ) ) ; 

ALTER TABLE FP_SUBMITTAL_MODEL_SQL ADD  CONSTRAINT FK_FP_SUBMITTAL_MODEL_1
 FOREIGN KEY (SUBMITTAL_MODEL_CODE) 
  REFERENCES FP_SUBMITTAL_MODEL (SUBMITTAL_MODEL_CODE) ;


CREATE TABLE FP_SUBMITTAL_PREPROCESS ( 
  SUBMITTAL_PREPROCESS_CODE      VARCHAR2 (50)  NOT NULL, 
  SUBMITTAL_PREPROCESS_DESC      VARCHAR2 (200)  NOT NULL, 
  PREPROCESS_MANAGER_CLASS_NAME  VARCHAR2 (100)  NOT NULL, 
  USER_LAST_UPDT                 VARCHAR2 (30)  NOT NULL, 
  TMSP_LAST_UPDT                 DATE          NOT NULL, 
  CONSTRAINT PK_FP_SUBMITTAL_PREPROCESS
  PRIMARY KEY ( SUBMITTAL_PREPROCESS_CODE ) ) ; 


CREATE TABLE FP_SUBMITTAL_PREPROCESS_PARAM ( 
  SUBMITTAL_PREPROCESS_CODE  VARCHAR2 (50)  NOT NULL, 
  PARAM_NAME                 VARCHAR2 (50)  NOT NULL, 
  PARAM_DESC                 VARCHAR2 (200)  NOT NULL, 
  VALUE_STRING               VARCHAR2 (4000), 
  VALUE_NUMBER               NUMBER (20,10), 
  VALUE_DATE                 DATE, 
  ACTIVE_FLAG                CHAR (1)      NOT NULL, 
  USER_LAST_UPDT             VARCHAR2 (30)  NOT NULL, 
  TMSP_LAST_UPDT             DATE          NOT NULL, 
  CONSTRAINT PK_FP_SUBMITTAL_PREPROC_PARAM
  PRIMARY KEY ( SUBMITTAL_PREPROCESS_CODE, PARAM_NAME ) ) ; 

ALTER TABLE FP_SUBMITTAL_PREPROCESS_PARAM ADD  CONSTRAINT FK_FP_SUBMITTAL_PREPROCESS_2
 FOREIGN KEY (SUBMITTAL_PREPROCESS_CODE) 
  REFERENCES FP_SUBMITTAL_PREPROCESS (SUBMITTAL_PREPROCESS_CODE) ;


CREATE TABLE FP_SUBMITTAL_PREPROCESS_XREF ( 
  SUBMITTAL_CODE             VARCHAR2 (50)  NOT NULL, 
  SUBMITTAL_PREPROCESS_CODE  VARCHAR2 (50)  NOT NULL, 
  ORDER_NUM                  NUMBER (2)    NOT NULL, 
  ACTIVE_FLAG                CHAR (1)      NOT NULL, 
  USER_LAST_UPDT             VARCHAR2 (30)  NOT NULL, 
  TMSP_LAST_UPDT             DATE          NOT NULL, 
  CONSTRAINT PK_FP_SUBMITTAL_PREPROC_XREF
  PRIMARY KEY ( SUBMITTAL_CODE, SUBMITTAL_PREPROCESS_CODE ) ) ; 

ALTER TABLE FP_SUBMITTAL_PREPROCESS_XREF ADD  CONSTRAINT FK_FP_SUBMITTAL_2
 FOREIGN KEY (SUBMITTAL_CODE) 
  REFERENCES FP_SUBMITTAL (SUBMITTAL_CODE) ;

ALTER TABLE FP_SUBMITTAL_PREPROCESS_XREF ADD  CONSTRAINT FK_FP_SUBMITTAL_PREPROCESS_1
 FOREIGN KEY (SUBMITTAL_PREPROCESS_CODE) 
  REFERENCES FP_SUBMITTAL_PREPROCESS (SUBMITTAL_PREPROCESS_CODE) ;


CREATE TABLE FP_SUBMITTAL_EXPORT ( 
  SUBMITTAL_EXPORT_CODE      VARCHAR2 (50)  NOT NULL, 
  SUBMITTAL_EXPORT_DESC      VARCHAR2 (200)  NOT NULL, 
  EXPORT_MANAGER_CLASS_NAME  VARCHAR2 (100)  NOT NULL, 
  USER_LAST_UPDT             VARCHAR2 (30)  NOT NULL, 
  TMSP_LAST_UPDT             DATE          NOT NULL, 
  CONSTRAINT PK_FP_SUBMITTAL_EXPORT
  PRIMARY KEY ( SUBMITTAL_EXPORT_CODE ) ) ; 


CREATE TABLE FP_SUBMITTAL_EXPORT_PARAM ( 
  SUBMITTAL_EXPORT_CODE  VARCHAR2 (50)  NOT NULL, 
  PARAM_NAME             VARCHAR2 (50)  NOT NULL, 
  PARAM_DESC             VARCHAR2 (200)  NOT NULL, 
  VALUE_STRING           VARCHAR2 (4000), 
  VALUE_NUMBER           NUMBER (20,10), 
  VALUE_DATE             DATE, 
  ACTIVE_FLAG            CHAR (1)      NOT NULL, 
  USER_LAST_UPDT         VARCHAR2 (30)  NOT NULL, 
  TMSP_LAST_UPDT         DATE          NOT NULL, 
  CONSTRAINT PK_FP_SUBMITTAL_EXPORT_PARAM
  PRIMARY KEY ( SUBMITTAL_EXPORT_CODE, PARAM_NAME ) ) ; 

ALTER TABLE FP_SUBMITTAL_EXPORT_PARAM ADD  CONSTRAINT FK_FP_SUBMITTAL_EXPORT_1
 FOREIGN KEY (SUBMITTAL_EXPORT_CODE) 
  REFERENCES FP_SUBMITTAL_EXPORT (SUBMITTAL_EXPORT_CODE) ;


CREATE TABLE FP_SUBMITTAL_EXPORT_XREF ( 
  SUBMITTAL_CODE         VARCHAR2 (50)  NOT NULL, 
  SUBMITTAL_EXPORT_CODE  VARCHAR2 (50)  NOT NULL, 
  ORDER_NUM              NUMBER (2)    NOT NULL, 
  ACTIVE_FLAG            CHAR (1)      NOT NULL, 
  USER_LAST_UPDT         VARCHAR2 (30)  NOT NULL, 
  TMSP_LAST_UPDT         DATE          NOT NULL, 
  CONSTRAINT PK_FP_SUBMITTAL_EXPORT_XREF
  PRIMARY KEY ( SUBMITTAL_CODE, SUBMITTAL_EXPORT_CODE ) ) ; 

ALTER TABLE FP_SUBMITTAL_EXPORT_XREF ADD  CONSTRAINT FK_FP_SUBMITTAL_1
 FOREIGN KEY (SUBMITTAL_CODE) 
  REFERENCES FP_SUBMITTAL (SUBMITTAL_CODE) ;

ALTER TABLE FP_SUBMITTAL_EXPORT_XREF ADD  CONSTRAINT FK_FP_SUBMITTAL_EXPORT_2
 FOREIGN KEY (SUBMITTAL_EXPORT_CODE) 
  REFERENCES FP_SUBMITTAL_EXPORT (SUBMITTAL_EXPORT_CODE) ;

